@@ -145,32 +145,68 @@ function processDeployment($queue_id, $config, $DockerAPI, $containerQueue, $db)
                 throw new Exception("Invalid container name generated from domain: " . $config['primary_fqdn']);
             }
             
-            // Prepare container configuration with proper data types
-            $container_config = [
-                'name' => $container_name,
-                'image' => $container_type_info['base_image'],
-                'cpu' => (float)$config['cpu_per_container'],
-                'memory' => (int)$config['memory_per_container'],
-                'user' => $config['primary_domain_row']['username'],
-                'listen_port' => (int)$container_type_info['listen_port']
-            ];
+            // Prepare environment variables
+            $env_vars = [];
             
-            // Add startup_env if it exists and is valid JSON
+            // Process startup environment variables
             if (!empty($container_type_info['startup_env'])) {
                 $startup_env = json_decode($container_type_info['startup_env'], true);
-                if ($startup_env !== null) {
-                    $container_config['startup_env'] = $startup_env;
+                if ($startup_env) {
+                    foreach ($startup_env as $var_name => $var_value) {
+                        // Replace dynamic variables (simplified version for queue processor)
+                        $var_value = str_replace(['{username}', '{domain}', '{container_number}'], 
+                                                [$config['primary_domain_row']['username'], 
+                                                 $config['primary_fqdn'], 
+                                                 $i], 
+                                                $var_value);
+                        $env_vars[] = $var_name . '=' . $var_value;
+                    }
                 }
             }
             
-            // Add mount_options if it exists and is valid JSON
+            // Prepare volumes
+            $volumes = [
+                '/docker/users/' . $config['primary_domain_row']['username'] . '/' . $config['primary_fqdn'] . ':/var/www/html'
+            ];
+            
+            // Process mount options
             if (!empty($container_type_info['mount_options'])) {
                 $mount_options = json_decode($container_type_info['mount_options'], true);
-                if ($mount_options !== null) {
-                    $container_config['mount_options'] = $mount_options;
+                if ($mount_options && isset($mount_options['volumes'])) {
+                    foreach ($mount_options['volumes'] as $volume) {
+                        // Replace dynamic variables in both source and target paths
+                        $source = str_replace(['{username}', '{domain}', '{container_number}'], 
+                                            [$config['primary_domain_row']['username'], 
+                                             $config['primary_fqdn'], 
+                                             $i], 
+                                            $volume['source']);
+                        $target = str_replace(['{username}', '{domain}', '{container_number}'], 
+                                            [$config['primary_domain_row']['username'], 
+                                             $config['primary_fqdn'], 
+                                             $i], 
+                                            $volume['target']);
+                        $volumes[] = $source . ':' . $target;
+                    }
                 }
             }
             
+            // Create container config matching the working sites.php format
+            $container_config = [
+                'image' => $container_type_info['base_image'],
+                'name' => $container_name,
+                'labels' => [
+                    'whp.user' => $config['primary_domain_row']['username'],
+                    'whp.domain' => $config['primary_fqdn'],
+                    'whp.site_id' => strval($config['site_id']),
+                    'whp.container_number' => strval($i)
+                ],
+                'env' => $env_vars,
+                'volumes' => $volumes,
+                'cpu' => (float)$config['cpu_per_container'],
+                'memory' => (int)$config['memory_per_container'],
+                'network' => 'client-net'
+            ];
+            
             $result = $DockerAPI->create_container($container_config);
             
             // Log only essential information, not sensitive config
